"use client"

import CustomCard from "@/components/card/Card";
import { Box, Button, Flex, FormControl, FormLabel, Text, useColorModeValue, useToast } from "@chakra-ui/react";
import FormComponent from "@/components/form/Form";
import { InputWrapper } from "@/components/fields/Fields";
import prepareValidationSchema, { FormObject } from "@/utils/validation-schema";
import { useRouter } from "next/navigation";
import { useEffect, useMemo, useRef, useState } from "react";
import { useGeneral } from "@/contexts/GeneralContext";
import { saveDivisionSetting } from "@/app/lib/setting/action";

interface formValues {
  club_share: string;
}

export default function DivisionSetting({ club_share, settingId }: { club_share: number; settingId: string | null }) {
  const { isAdmin } = useGeneral();
  // Chakra hooks
  const toast = useToast();
  const router = useRouter();

  // page styles
  const textColor = useColorModeValue("secondaryGray.900", "white");
  const brandStars = useColorModeValue("brand.500", "brand.400");

  const formFields: FormObject[] = [
    {
      name: "club_share",
      label: "Club Share",
      type: "number",
      defaultValue: club_share,
      min: 0,
      max: 10,
      required: true,
    },
  ];

  // logic values
  const formRef = useRef(null);
  const [dynamicFormField, setDynamicFormField] = useState(formFields);
  const formDetails = useMemo(() => prepareValidationSchema(dynamicFormField), [dynamicFormField]);
  const [divisionForm, setDivisionForm] = useState({});
  const { initialFormData, validationSchema } = formDetails;
  const [formValidationSchema, setFormValidationSchema] = useState({});

  useEffect(() => {
    setDivisionForm(initialFormData);
    setFormValidationSchema(validationSchema);
  }, [initialFormData, validationSchema]);

  const handleSubmit = async (values: { club_share: string }, data: object) => {
    
    const payload = {
      club_share: parseInt(values.club_share),
    };
    const res = await saveDivisionSetting(settingId, payload);
    
    if (res.status == 200 || res.status) {
      toast({
        title: "200",
        description: res.message,
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      router.refresh();
    } else {
      toast({
        title: res.status,
        description: res.error,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };

  if (isAdmin) {
    return null;
  }

  return (
    <CustomCard w="100%">
      <Flex align="center" justifyContent="space-between" w="100%" px="15px" py="10px">
        <Text color={textColor} fontSize="xl" fontWeight="700" lineHeight="100%">
          Division Setting
        </Text>
      </Flex>
      <Flex align="center" w="100%">
        <FormComponent
          ref={formRef}
          validationSchema={formValidationSchema}
          initialValues={divisionForm}
          submitForm={(formValues, formData) => {
            handleSubmit(formValues, formData);
          }}>
          <FormControl w="full">
            <Flex gap={8}>
              <Flex flexDirection="column">
                <FormLabel display="flex" ms="4px" fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                  Club Share<Text color={brandStars}>*</Text>
                </FormLabel>
                <InputWrapper form={true} fieldName="club_share" defaultValue={dynamicFormField[0].defaultValue} id="email" placeholder="0" variant="auth" w="full" mb="2px" fontSize="sm" ms={{ base: "0px", md: "0px" }} type="number" fontWeight="500" size="lg" />
              </Flex>
            </Flex>
            <Button fontSize="sm" type="submit" variant="brand" fontWeight="500" h="50" mb="28px">
              Save
            </Button>
          </FormControl>
        </FormComponent>
      </Flex>
    </CustomCard>
  );
}
